@@ -19,14 +19,18 @@
 
 #include "medianotifier.h"
 
-#if defined (__OpenBSD__) || defined(__FreeBSD__) || defined(__NetBSD__)
+#if defined (__OpenBSD__) || defined(__FreeBSD__) || defined(__NetBSD__)\
+ || defined(Q_OS_SOLARIS)
+#ifdef Q_OS_SOLARIS
+#include <sys/types.h>
+#endif /* Q_OS_SOLARIS */
 #include <sys/statvfs.h>
 #include <sys/param.h>
 #include <sys/mount.h>
 #else
 #include <sys/vfs.h>
 #endif
-#if defined(__NetBSD__)
+#if defined(__NetBSD__) || defined(Q_OS_SOLARIS)
 #define statfs statvfs
 #endif
 
@@ -65,7 +69,7 @@ MediaNotifier::MediaNotifier(const TQCString &name) : KDEDModule(name)
 
 	m_notificationDialogList.setAutoDelete(FALSE);
 	m_freeTimer = new TQTimer( this );
-	connect( m_freeTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( checkFreeDiskSpace() ) );
+	connect( m_freeTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( checkFreeDiskSpace() ) );
 	m_freeTimer->start( 1000*6*2 /* 20 minutes */ );
 	m_freeDialog = 0;
 }
@@ -119,8 +123,8 @@ void MediaNotifier::onMediumChange( const TQString &name, bool allowNotification
 
 	m_allowNotificationMap[job] = allowNotification;
 	
-	connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ),
-	         this, TQT_SLOT( slotStatResult( TDEIO::Job * ) ) );
+	connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ),
+	         this, TQ_SLOT( slotStatResult( TDEIO::Job * ) ) );
 }
 
 void MediaNotifier::slotStatResult( TDEIO::Job *job )
@@ -146,7 +150,7 @@ bool MediaNotifier::autostart( const KFileItem &medium )
 {
 	TQString mimetype = medium.mimetype();
 
-	bool is_cdrom = mimetype.startsWith( "media/cd" ) || mimetype.startsWith( "media/dvd" );
+	bool is_cdrom = mimetype.startsWith( "media/cd" ) || mimetype.startsWith( "media/dvd" ) || mimetype.startsWith( "media/bluray" );
 	bool is_mounted = mimetype.contains( "_mounted" );
 	
 	// We autorun only on CD/DVD or removable disks (USB, Firewire)
@@ -343,7 +347,7 @@ void MediaNotifier::notify( KFileItem &medium )
 		if ( actions.size()>1 )
 		{
 			NotificationDialog*  notifier = new NotificationDialog( medium, settings );
-			connect(notifier, TQT_SIGNAL(destroyed(TQObject*)), this, TQT_SLOT(notificationDialogDestroyed(TQObject*)));
+			connect(notifier, TQ_SIGNAL(destroyed(TQObject*)), this, TQ_SLOT(notificationDialogDestroyed(TQObject*)));
 			m_notificationDialogList.append(notifier);
 			notifier->show();
 		}
@@ -403,8 +407,8 @@ void MediaNotifier::checkFreeDiskSpace()
                                            i18n("Do not ask again"),
                                            &checkboxResult, KMessageBox::Notify | KMessageBox::NoExec);
             m_freeDialog->show();
-            connect( m_freeDialog, TQT_SIGNAL( yesClicked() ), TQT_SLOT( slotFreeContinue() ) );
-            connect( m_freeDialog, TQT_SIGNAL( noClicked() ), TQT_SLOT( slotFreeCancel() ) );
+            connect( m_freeDialog, TQ_SIGNAL( yesClicked() ), TQ_SLOT( slotFreeContinue() ) );
+            connect( m_freeDialog, TQ_SIGNAL( noClicked() ), TQ_SLOT( slotFreeCancel() ) );
         }
     }
 }
@@ -421,7 +425,7 @@ void MediaNotifier::slotFreeCancel()
 
 void MediaNotifier::slotFreeFinished( KMessageBox::ButtonCode res )
 {
-    TQCheckBox *checkbox = ::tqqt_cast<TQCheckBox*>( m_freeDialog->child( 0, TQCHECKBOX_OBJECT_NAME_STRING ) );
+    TQCheckBox *checkbox = ::tqt_cast<TQCheckBox*>( m_freeDialog->child( 0, "TQCheckBox" ) );
     if ( checkbox && checkbox->isChecked() )
         KMessageBox::saveDontShowAgainYesNo("dontagainfreespace", res);
     m_freeDialog->delayedDestruct();
