@@ -146,7 +146,7 @@ Application::Application( )
             ::exit(1);
             }
         }
-    connect( &owner, TQT_SIGNAL( lostOwnership()), TQT_SLOT( lostSelection()));
+    connect( &owner, TQ_SIGNAL( lostOwnership()), TQ_SLOT( lostSelection()));
     
     // if there was already twin running, it saved its configuration after loosing the selection -> reread
     config()->reparseConfiguration();
@@ -194,7 +194,7 @@ Application::~Application()
     delete Workspace::self();
     if( owner.ownerWindow() != None ) // if there was no --replace (no new WM)
         {
-        XSetInputFocus( tqt_xdisplay(), PointerRoot, RevertToPointerRoot, GET_QT_X_TIME() );
+        XSetInputFocus( tqt_xdisplay(), PointerRoot, RevertToPointerRoot, get_tqt_x_time() );
         DCOPRef ref( "kded", "kded" );
         if( !ref.send( "loadModule", TQCString( "kdetrayproxy" )))
             kdWarning( 176 ) << "Loading of kdetrayproxy failed." << endl;
