@@ -51,13 +51,13 @@ TQPopupMenu* Workspace::clientPopup()
         popup = new TQPopupMenu;
         popup->setCheckable( TRUE );
         popup->setFont(TDEGlobalSettings::menuFont());
-        connect( popup, TQT_SIGNAL( aboutToShow() ), this, TQT_SLOT( clientPopupAboutToShow() ) );
-        connect( popup, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( clientPopupActivated(int) ) );
+        connect( popup, TQ_SIGNAL( aboutToShow() ), this, TQ_SLOT( clientPopupAboutToShow() ) );
+        connect( popup, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( clientPopupActivated(int) ) );
       
         advanced_popup = new TQPopupMenu( popup );
         advanced_popup->setCheckable( TRUE );
         advanced_popup->setFont(TDEGlobalSettings::menuFont());
-        connect( advanced_popup, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( clientPopupActivated(int) ) );
+        connect( advanced_popup, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( clientPopupActivated(int) ) );
         advanced_popup->insertItem( SmallIconSet( "go-up" ),
             i18n("Keep &Above Others")+'\t'+keys->shortcut("Window Above Other Windows").seq(0).toString(), Options::KeepAboveOp );
         advanced_popup->insertItem( SmallIconSet( "go-down" ),
@@ -85,11 +85,11 @@ TQPopupMenu* Workspace::clientPopup()
             TQToolTip::add(transButton, i18n("Reset opacity to default value"));
             transSlider = new TQSlider(0, 100, 1, 100, TQt::Horizontal, transBox, "transSlider");
             TQToolTip::add(transSlider, i18n("Slide this to set the window's opacity"));
-            connect(transButton, TQT_SIGNAL(clicked()), TQT_SLOT(resetClientOpacity()));
-            connect(transButton, TQT_SIGNAL(clicked()), trans_popup, TQT_SLOT(hide()));
-            connect(transSlider, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(setTransButtonText(int)));
-            connect(transSlider, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(setPopupClientOpacity(int)));
-//             connect(transSlider, TQT_SIGNAL(sliderReleased()), trans_popup, TQT_SLOT(hide()));
+            connect(transButton, TQ_SIGNAL(clicked()), TQ_SLOT(resetClientOpacity()));
+            connect(transButton, TQ_SIGNAL(clicked()), trans_popup, TQ_SLOT(hide()));
+            connect(transSlider, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(setTransButtonText(int)));
+            connect(transSlider, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(setPopupClientOpacity(int)));
+//             connect(transSlider, TQ_SIGNAL(sliderReleased()), trans_popup, TQ_SLOT(hide()));
             trans_popup->insertItem(transBox);
             popup->insertItem(i18n("&Opacity"), trans_popup );
         }
@@ -105,7 +105,7 @@ TQPopupMenu* Workspace::clientPopup()
         if (!TDEGlobal::config()->isImmutable() && 
             !kapp->authorizeControlModules(Workspace::configModules(true)).isEmpty())
             {
-            popup->insertItem(SmallIconSet( "configure" ), i18n("Configur&e Window Behavior…"), this, TQT_SLOT( configureWM() ));
+            popup->insertItem(SmallIconSet( "configure" ), i18n("Configur&e Window Behavior…"), this, TQ_SLOT( configureWM() ));
             popup->insertSeparator();
             }
 
@@ -201,10 +201,10 @@ void Workspace::initDesktopPopup()
     desk_popup = new TQPopupMenu( popup );
     desk_popup->setCheckable( TRUE );
     desk_popup->setFont(TDEGlobalSettings::menuFont());
-    connect( desk_popup, TQT_SIGNAL( activated(int) ),
-             this, TQT_SLOT( slotSendToDesktop(int) ) );
-    connect( desk_popup, TQT_SIGNAL( aboutToShow() ),
-             this, TQT_SLOT( desktopPopupAboutToShow() ) );
+    connect( desk_popup, TQ_SIGNAL( activated(int) ),
+             this, TQ_SLOT( slotSendToDesktop(int) ) );
+    connect( desk_popup, TQ_SIGNAL( aboutToShow() ),
+             this, TQ_SLOT( desktopPopupAboutToShow() ) );
 
     popup->insertItem(i18n("To &Desktop"), desk_popup, -1, desk_popup_index );
     }
@@ -299,7 +299,7 @@ void Workspace::setupWindowShortcut( Client* c )
     client_keys->suspend( true );
     client_keys_dialog = new ShortcutDialog( c->shortcut());
     client_keys_client = c;
-    connect( client_keys_dialog, TQT_SIGNAL( dialogDone( bool )), TQT_SLOT( setupWindowShortcutDone( bool )));
+    connect( client_keys_dialog, TQ_SIGNAL( dialogDone( bool )), TQ_SLOT( setupWindowShortcutDone( bool )));
     TQRect r = clientArea( ScreenArea, c );
     TQSize size = client_keys_dialog->sizeHint();
     TQPoint pos = c->pos() + c->clientPos();
@@ -336,7 +336,7 @@ void Workspace::clientShortcutUpdated( Client* c )
         {
         client_keys->insert( key, key );
         client_keys->setShortcut( key, c->shortcut());
-        client_keys->setSlot( key, c, TQT_SLOT( shortcutActivated()));
+        client_keys->setSlot( key, c, TQ_SLOT( shortcutActivated()));
         client_keys->setActionEnabled( key, true );
         }
     client_keys->updateConnections();
@@ -647,12 +647,70 @@ bool Client::performMouseCommand( Options::MouseCommand command, TQPoint globalP
     return replay;
     }
 
-// KDE4 remove me
-void Workspace::showWindowMenuAt( unsigned long, int, int )
+void Workspace::showWindowMenuAt( unsigned long window, int x, int y )
     {
-    slotWindowOperations();
+    Client *client;
+    if ((client = findClient(WindowMatchPredicate((WId)window))))
+        showWindowMenu( x, y, client );
     }
 
+void Workspace::showWindowMenu( unsigned long window )
+    {
+    Client *client;
+    if ((client = findClient(WindowMatchPredicate((WId)window))))
+        {
+        TQPoint pos = client->pos() + client->clientPos();
+        showWindowMenu( pos, client );
+        }
+    }
+
+void Workspace::tileWindowToBorder(unsigned long w1, int location) {
+    if (location < ActiveTop || location >= ACTIVE_BORDER_COUNT) return;
+
+    Client *c1 = findClient(WindowMatchPredicate((WId)w1));
+    if (!c1) return;
+
+    c1->tileToBorder((ActiveBorder)location);
+}
+
+void Workspace::tileTwoWindowsHorizontally(unsigned long w1, unsigned long w2) {
+    if (w1 == w2) return;
+
+    Client *c1 = findClient(WindowMatchPredicate((WId)w1));
+    Client *c2 = findClient(WindowMatchPredicate((WId)w2));
+    if (!c1 || !c2) return;
+
+    c1->tileToBorder(ActiveTop);
+    c2->tileToBorder(ActiveBottom);
+}
+
+void Workspace::tileTwoWindowsVertically(unsigned long w1, unsigned long w2) {
+    if (w1 == w2) return;
+
+    Client *c1 = findClient(WindowMatchPredicate((WId)w1));
+    Client *c2 = findClient(WindowMatchPredicate((WId)w2));
+    if (!c1 || !c2) return;
+
+    c1->tileToBorder(ActiveLeft);
+    c2->tileToBorder(ActiveRight);
+}
+
+void Workspace::tileFourWindowsInGrid(unsigned long w1, unsigned long w2, unsigned long w3, unsigned long w4) {
+    if (w1 == w2 || w1 == w3 || w1 == w4 || w2 == w3 || w2 == w4 || w3 == w4)
+        return;
+
+    Client *c1 = findClient(WindowMatchPredicate((WId)w1));
+    Client *c2 = findClient(WindowMatchPredicate((WId)w2));
+    Client *c3 = findClient(WindowMatchPredicate((WId)w3));
+    Client *c4 = findClient(WindowMatchPredicate((WId)w4));
+    if (!c1 || !c2 || !c3 || !c4) return;
+
+    c1->tileToBorder(ActiveTopLeft);
+    c2->tileToBorder(ActiveTopRight);
+    c3->tileToBorder(ActiveBottomLeft);
+    c4->tileToBorder(ActiveBottomRight);
+}
+
 void Workspace::slotActivateAttentionWindow()
     {
     if( attention_chain.count() > 0 )
@@ -1070,17 +1128,21 @@ void Workspace::showWindowMenu( const TQRect &pos, Client* cl )
     active_popup = p;
     int x = pos.left();
     int y = pos.bottom();
-    if (y == pos.top())
-	p->exec( TQPoint( x, y ) );
+    clientPopupAboutToShow(); // needed for sizeHint() to be correct :-/
+
+    TQRect area = clientArea(ScreenArea, TQPoint(x, y), currentDesktop());
+    TQSize hint = p->sizeHint();
+    if (x < 0) x = area.right() - hint.width() + x;
+    if (y < 0) y = area.bottom() - hint.height() + y;
+
+    if (pos.bottom() == pos.top())
+        p->exec( TQPoint( x, y ) );
     else
         {
-	TQRect area = clientArea(ScreenArea, TQPoint(x, y), currentDesktop());
-        clientPopupAboutToShow(); // needed for sizeHint() to be correct :-/
-	int popupHeight = p->sizeHint().height();
-	if (y + popupHeight < area.height())
-	    p->exec( TQPoint( x, y ) );
-	else
-	    p->exec( TQPoint( x, pos.top() - popupHeight ) );
+        if (y + hint.height() < area.height())
+            p->exec( TQPoint( x, y ) );
+        else
+            p->exec( TQPoint( x, pos.top() - hint.height() ) );
         }
     // active popup may be already changed (e.g. the window shortcut dialog)
     if( active_popup == p )
